@@ -1,6 +1,6 @@
 package School::Code::Compare;
-# ABSTRACT: Calculate the difference between two strings
-$School::Code::Compare::VERSION = '0.001'; # TRIAL
+# ABSTRACT: 'naive' metrics for code similarity
+$School::Code::Compare::VERSION = '0.006'; # TRIAL
 use strict;
 use warnings;
 
@@ -118,29 +118,87 @@ __END__
 
 =head1 NAME
 
-School::Code::Compare - Calculate the difference between two strings
+School::Code::Compare - 'naive' metrics for code similarity
 
 =head1 VERSION
 
-version 0.001
+version 0.006
 
 =head1 SYNOPSIS
 
+This distribution ships a script.
+You migth want to look at the script L<compare-code> in the C<bin> directory.
+For documentation of the used libraries, keep on reading.
+
+This calculates the Levenshtein Difference for two files, if they meet certain criterias:
+
+ use School::Code::Compare;
+
  my $comparer   = School::Code::Compare->new()                                    
                                        ->set_max_char_difference(400)             
                                        ->set_min_char_total     ( 20)             
                                        ->set_max_distance       (400);
  
- my $comparison = $comparer->measure( $files[$i]->{"code_$algo"},
-                                      $files[$j]->{"code_$algo"}      
+ my $comparison = $comparer->measure( 'use strict; print "Hello\n";',
+                                      'use v5.22; say "Hello";'
                                     ); 
 
-=head1 BIN / SCRIPT
+ print $comparison->{distance} if $comparison   # 13
 
-This distribution ships a script.
-You migth want to look at the script C<compare-code> in the bin directory.
+=head1 FUNCTIONS
 
-For documentation of the used libraries, keep on reading.
+=head2 set_max_char_difference
+
+Don't even start comparison, if the difference in char count is higher than set.
+
+=head2 set_min_char_total
+
+Don't even start comparison if a file is below this char count.
+
+=head2 set_max_distance
+
+Abort comparison (in the midst of comparison), if distance is becoming higher then set value.
+
+=head2 measure
+
+Do a comparison for two strings.
+Gives back a hash reference with different information:
+
+ # (example output from synopsis)
+ {
+   'distance'     => 13,
+   'ratio'        => 50,
+   'comment'      => 'comparison done',
+   'delta_length' => 5
+ };
+
+=over 4
+
+=item distance
+
+The Levenshtein Distance.
+See L<Text::Levenshtein::XS> for more information.
+
+=item ratio
+
+The ratio of the distance in chars to the average length of the compared strings.
+A ratio of zero means, the strings are similar.
+A ratio of 50 means, that 50% of a string is different.
+
+My experience is, that if you get a ratio below 30% you have to start looking if the code was copied and altered (if your concern is to find 'cheaters' in educational/school environments).
+This method of measurement is by no means well established.
+It may be even 'naive', but it just seems to work out quite well.
+See L<School::Code::Compare::Judge> to see, how the results are currently interpreted.
+
+=item comment
+
+A comment on how the comparison went.
+
+=item delta_length
+
+Difference in length (chars) of the two compared strings.
+
+=back
 
 =head1 AUTHOR
 
